Module: Plutonium::Testing::ResourceCrud
- Extended by:
- ActiveSupport::Concern
- Includes:
- AuthHelpers, DSL
- Defined in:
- lib/plutonium/testing/resource_crud.rb
Constant Summary
Constants included
from DSL
DSL::DEFAULT_ACTIONS
Instance Method Summary
collapse
#current_account, #login_as, #sign_out, #with_portal
Methods included from DSL
#current_path_prefix, #current_portal
Instance Method Details
#create_resource! ⇒ Object
77
78
79
|
# File 'lib/plutonium/testing/resource_crud.rb', line 77
def create_resource!
raise NotImplementedError, "Override #create_resource! to return a persisted record"
end
|
#valid_create_params ⇒ Object
81
82
83
|
# File 'lib/plutonium/testing/resource_crud.rb', line 81
def valid_create_params
raise NotImplementedError, "Override #valid_create_params to return a Hash of valid attributes for POST"
end
|
#valid_update_params ⇒ Object
85
86
87
|
# File 'lib/plutonium/testing/resource_crud.rb', line 85
def valid_update_params
raise NotImplementedError, "Override #valid_update_params to return a Hash of valid attributes for PATCH"
end
|