Exception: Plutonium::Interaction::Async::Context::PolicyMismatchError
- Inherits:
-
UnresolvableError
- Object
- StandardError
- UnresolvableError
- Plutonium::Interaction::Async::Context::PolicyMismatchError
- Defined in:
- lib/plutonium/interaction/async/context.rb
Overview
Raised when the policy resolved now is not the policy dispatch resolved. A subclass so a caller can rescue either the specific case or every "this run cannot be trusted" case with one rescue.