Module: Plutonium::Resource::Controllers::Authorizable
- Extended by:
- ActiveSupport::Concern
- Included in:
- Plutonium::Resource::Controller
- Defined in:
- lib/plutonium/resource/controllers/authorizable.rb
Overview
Note:
This module assumes the existence of methods like ‘resource_record!`, `resource_class`, `current_parent`, and `entity_scope_for_authorize`.
The Authorizable module provides authorization functionality for controllers, specifically for the current resource being handled by the controller. It integrates with ActionPolicy to enforce authorization checks and scoping.
Defined Under Namespace
Classes: ActionMissingAuthorizeCurrent, ActionMissingCurrentAuthorizedScope